==> edge-login-ui-rn-2.1.0.tgz: package/lib/components/scenes/ChangePasswordScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard, KeyboardAvoidingView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validateConfirmPassword, validatePassword } from '../../actions/CreateAccountActions';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler.js';
import { useImports } from '../../hooks/useImports';
import { useDispatch, useSelector } from '../../types/ReduxTypes';
import { logEvent } from '../../util/analytics';
import { WarningCard } from '../common/WarningCard';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { Fade } from '../themed/Fade';
import { FormError } from '../themed/FormError';
import { MainButton } from '../themed/MainButton';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { PasswordStatus } from '../themed/PasswordStatus';
import { ThemedScene } from '../themed/ThemedScene';
const ChangePasswordSceneComponent = ({ title, onBack, onSkip, onSubmit, mainButtonLabel = s.strings.done }) => {
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const [focusFirst, setFocusFirst] = React.useState(true);
    const [focusSecond, setFocusSecond] = React.useState(false);
    const [hidePassword, setHidePassword] = React.useState(true);
    const [spinning, setSpinning] = React.useState(false);
    const [isShowError, setIsShowError] = React.useState(false);
    const hasPasswordStatus = useSelector(state => state.passwordStatus != null);
    const isRequirementsMet = useSelector(state => { var _a, _b; return (_b = (_a = state.passwordStatus) === null || _a === void 0 ? void 0 : _a.passed) !== null && _b !== void 0 ? _b : false; });
    const password = useSelector(state => { var _a; return (_a = state.create.password) !== null && _a !== void 0 ? _a : ''; });
    const confirmPassword = useSelector(state => { var _a; return (_a = state.create.confirmPassword) !== null && _a !== void 0 ? _a : ''; });
    const confirmPasswordErrorMessage = useSelector(state => { var _a; return (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : ''; });
    const handleHidePassword = useHandler(() => {
        setHidePassword(!hidePassword);
    });
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!isRequirementsMet)
            return;
        if (password !== confirmPassword) {
            setIsShowError(true);
            return;
        }
        setSpinning(true);
        try {
            yield onSubmit(password);
        }
        catch (e) {
            showError(e);
            setSpinning(false);
        }
    }));
    const handleFocusSwitch = () => {
        setFocusFirst(false);
        setFocusSecond(true);
    };
    const validatePasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validatePassword(password));
    };
    const validateConfirmPasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validateConfirmPassword(password));
    };
    const renderInterior = () => {
        return (React.createElement(React.Fragment, null,
            hasPasswordStatus ? (React.createElement(PasswordStatus, { marginRem: [0.5, 0.5, 1.25] })) : (React.createElement(EdgeText, { style: styles.description, numberOfLines: 4 }, s.strings.password_desc)),
            React.createElement(OutlinedTextInput, { value: password, secureTextEntry: true, returnKeyType: "next", label: s.strings.password, autoFocus: focusFirst, hidePassword: hidePassword, onChangeText: validatePasswordDispatch, onSubmitEditing: handleFocusSwitch, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(OutlinedTextInput, { value: confirmPassword, secureTextEntry: true, returnKeyType: "go", label: s.strings.confirm_password, autoFocus: focusSecond, hidePassword: hidePassword, onChangeText: validateConfirmPasswordDispatch, onSubmitEditing: handlePress, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(FormError, { marginRem: [0, 0.75], invisible: !isShowError }, confirmPasswordErrorMessage),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: !isShowError, hidden: true }, spinning ? (React.createElement(MainButton, { alignSelf: "center", disabled: true, marginRem: 0.5, type: "secondary", spinner: true })) : (React.createElement(MainButton, { alignSelf: "center", label: mainButtonLabel, disabled: !isRequirementsMet || confirmPassword === '', marginRem: 0.5, onPress: handlePress, type: "secondary" }))))));
    };
    return (React.createElement(ThemedScene, { onBack: onBack, onSkip: onSkip, title: title }, focusSecond ? (React.createElement(KeyboardAvoidingView, { style: styles.container, behavior: "position", keyboardVerticalOffset: -150 }, renderInterior())) : (React.createElement(View, { style: styles.container }, renderInterior()))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        overflow: 'hidden'
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25),
        marginTop: theme.rem(1.5)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(1)
    }
}));
// The scene for existing users to change their password
export const ChangePasswordScene = (props) => {
    const { route } = props;
    const { account } = route.params;
    const { onComplete } = useImports();
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } },
            React.createElement(WarningCard, { title: s.strings.warning, header: s.strings.password_change_warning, marginRem: [1, 0.5] }))));
        onComplete();
    }));
    return React.createElement(ChangePasswordSceneComponent, { onSubmit: handleSubmit });
};
// The scene for existing users to recover their password
export const ResecurePasswordScene = (props) => {
    const { route } = props;
    const { account } = route.params;
    const dispatch = useDispatch();
    const handleSkip = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePin', params: { account } }
        });
    });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePin', params: { account } }
        });
    }));
    return (React.createElement(ChangePasswordSceneComponent, { onSkip: handleSkip, title: s.strings.change_password, onSubmit: handleSubmit }));
};
// The scene for new users to create a password
export const NewAccountPasswordScene = (props) => {
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountUsername', params: {} }
        });
    });
    const handleSubmit = useHandler(() => {
        logEvent('Signup_Password_Valid');
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountPin', params: {} }
        });
    });
    return (React.createElement(ChangePasswordSceneComponent, { onBack: handleBack, onSubmit: handleSubmit, title: s.strings.choose_title_password, mainButtonLabel: s.strings.next_label }));
};

==> edge-login-ui-rn-2.3.0.tgz: package/lib/components/scenes/ChangePasswordScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard, KeyboardAvoidingView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validateConfirmPassword, validatePassword } from '../../actions/CreateAccountActions';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler.js';
import { useImports } from '../../hooks/useImports';
import { useDispatch, useSelector } from '../../types/ReduxTypes';
import { logEvent } from '../../util/analytics';
import { WarningCard } from '../common/WarningCard';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { Fade } from '../themed/Fade';
import { FormError } from '../themed/FormError';
import { MainButton } from '../themed/MainButton';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { PasswordStatus } from '../themed/PasswordStatus';
import { ThemedScene } from '../themed/ThemedScene';
const ChangePasswordSceneComponent = ({ title, onBack, onSkip, onSubmit, mainButtonLabel = s.strings.done }) => {
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const [focusFirst, setFocusFirst] = React.useState(true);
    const [focusSecond, setFocusSecond] = React.useState(false);
    const [hidePassword, setHidePassword] = React.useState(true);
    const [spinning, setSpinning] = React.useState(false);
    const [isShowError, setIsShowError] = React.useState(false);
    const hasPasswordStatus = useSelector(state => state.passwordStatus != null);
    const isRequirementsMet = useSelector(state => { var _a, _b; return (_b = (_a = state.passwordStatus) === null || _a === void 0 ? void 0 : _a.passed) !== null && _b !== void 0 ? _b : false; });
    const password = useSelector(state => { var _a; return (_a = state.create.password) !== null && _a !== void 0 ? _a : ''; });
    const confirmPassword = useSelector(state => { var _a; return (_a = state.create.confirmPassword) !== null && _a !== void 0 ? _a : ''; });
    const confirmPasswordErrorMessage = useSelector(state => { var _a; return (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : ''; });
    const handleHidePassword = useHandler(() => {
        setHidePassword(!hidePassword);
    });
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!isRequirementsMet)
            return;
        if (password !== confirmPassword) {
            setIsShowError(true);
            return;
        }
        setSpinning(true);
        try {
            yield onSubmit(password);
        }
        catch (e) {
            showError(e);
            setSpinning(false);
        }
    }));
    const handleFocusSwitch = () => {
        setFocusFirst(false);
        setFocusSecond(true);
    };
    const validatePasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validatePassword(password));
    };
    const validateConfirmPasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validateConfirmPassword(password));
    };
    const renderInterior = () => {
        return (React.createElement(React.Fragment, null,
            hasPasswordStatus ? (React.createElement(PasswordStatus, { marginRem: [0.5, 0.5, 1.25] })) : (React.createElement(EdgeText, { style: styles.description, numberOfLines: 4 }, s.strings.password_desc)),
            React.createElement(OutlinedTextInput, { value: password, secureTextEntry: true, returnKeyType: "next", label: s.strings.password, autoFocus: focusFirst, hidePassword: hidePassword, onChangeText: validatePasswordDispatch, onSubmitEditing: handleFocusSwitch, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(OutlinedTextInput, { value: confirmPassword, secureTextEntry: true, returnKeyType: "go", label: s.strings.confirm_password, autoFocus: focusSecond, hidePassword: hidePassword, onChangeText: validateConfirmPasswordDispatch, onSubmitEditing: handlePress, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(FormError, { marginRem: [0, 0.75], invisible: !isShowError }, confirmPasswordErrorMessage),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: !isShowError, hidden: true }, spinning ? (React.createElement(MainButton, { alignSelf: "center", disabled: true, marginRem: 0.5, type: "secondary", spinner: true })) : (React.createElement(MainButton, { alignSelf: "center", label: mainButtonLabel, disabled: !isRequirementsMet || confirmPassword === '', marginRem: 0.5, onPress: handlePress, type: "secondary" }))))));
    };
    return (React.createElement(ThemedScene, { onBack: onBack, onSkip: onSkip, title: title }, focusSecond ? (React.createElement(KeyboardAvoidingView, { style: styles.container, behavior: "position", keyboardVerticalOffset: -150 }, renderInterior())) : (React.createElement(View, { style: styles.container }, renderInterior()))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        overflow: 'hidden'
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25),
        marginTop: theme.rem(1.5)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(1)
    }
}));
// The scene for existing users to change their password
export const ChangePasswordScene = (props) => {
    const { route } = props;
    const { account } = route.params;
    const { onComplete = () => { } } = useImports();
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } },
            React.createElement(WarningCard, { title: s.strings.warning, header: s.strings.password_change_warning, marginRem: [1, 0.5] }))));
        onComplete();
    }));
    return React.createElement(ChangePasswordSceneComponent, { onSubmit: handleSubmit });
};
// The scene for existing users to recover their password
export const ResecurePasswordScene = (props) => {
    const { route } = props;
    const { account } = route.params;
    const dispatch = useDispatch();
    const handleSkip = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePin', params: { account } }
        });
    });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'resecurePin', params: { account } }
        });
    }));
    return (React.createElement(ChangePasswordSceneComponent, { onSkip: handleSkip, title: s.strings.change_password, onSubmit: handleSubmit }));
};
// The scene for new users to create a password
export const NewAccountPasswordScene = (props) => {
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountUsername', params: {} }
        });
    });
    const handleSubmit = useHandler(() => {
        logEvent('Signup_Password_Valid');
        dispatch({
            type: 'NAVIGATE',
            data: { name: 'newAccountPin', params: {} }
        });
    });
    return (React.createElement(ChangePasswordSceneComponent, { onBack: handleBack, onSubmit: handleSubmit, title: s.strings.choose_title_password, mainButtonLabel: s.strings.next_label }));
};
